###################################################################################################
# zmssysfolder.py
#
# Implementation of class ZMSSysFolder (see below).
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###################################################################################################

# Imports.
from Globals import HTML, HTMLFile
import string 
import urllib
import time
# Product Imports.
from zmsobject import ZMSObject
from zmscontainerobject import ZMSContainerObject
import _globals


###################################################################################################
###################################################################################################
###   
###   C o n s t r u c t o r ( s )
###   
###################################################################################################
###################################################################################################

manage_addZMSSysFolderForm = HTMLFile('manage_addzmssysfolderform', globals()) 
def manage_addZMSSysFolder(self, lang, manage_lang, _sort_id, REQUEST):
  """ manage_addZMSSysFolder """
  
  if REQUEST['btn'] == self.getLangStr('BTN_INSERT',manage_lang):
    
    ##### Create ####
    obj = ZMSSysFolder(self.getNewId(),_sort_id+1)
    self._setObject(obj.id, obj)
        
    oItem = getattr(self,obj.id)
    ##### Object State ####
    oItem.setObjStateNew(REQUEST)
    ##### Init Properties ####
    oItem.manage_changeProperties(lang,manage_lang,REQUEST)
    ##### VersionManager ####
    oItem.__autoCommit__(REQUEST)

    ##### Normalize Sort-IDs ####
    self.normalizeSortIds()
                
    # Return with message.
    message = self.getLangStr('MSG_INSERTED',manage_lang)%obj.display_type(REQUEST)
    if REQUEST.RESPONSE:
      REQUEST.RESPONSE.redirect('%s/%s/manage_main?lang=%s&manage_lang=%s&manage_tabs_message=%s'%(self.absolute_url(),obj.id,lang,manage_lang,urllib.quote(message)))
          
  else:         
    if REQUEST.RESPONSE:
      REQUEST.RESPONSE.redirect('%s/manage_main?lang=%s&manage_lang=%s'%(self.absolute_url(),lang,manage_lang))


###################################################################################################
###################################################################################################
###   
###   C l a s s
###   
###################################################################################################
###################################################################################################

class ZMSSysFolder(ZMSContainerObject):
        
    # Properties.
    # -----------
    meta_type = "ZMSSysFolder"
    icon = "misc_/zms/zmssysfolder.gif"
    icon_disabled = "misc_/zms/zmssysfolder_disabled.gif"

    # Management Options.
    # -------------------
    manage_options = ( 
	{'label': 'TAB_EDIT',       'action': 'manage_main'},
	{'label': 'TAB_PROPERTIES', 'action': 'manage_properties'},
	{'label': 'TAB_SECURITY',   'action': 'manage_access'},
	{'label': 'TAB_UNDO',       'action': 'manage_UndoForm'},
	{'label': 'TAB_OWNERSHIP',  'action': 'manage_owner'},
	{'label': 'TAB_SEARCH',     'action': 'manage_FindForm'},
	{'label': 'TAB_PREVIEW',    'action': 'preview_html'}, # empty string defaults to index_html
	)

    # Management Permissions.
    # -----------------------
    __authorPermissions__ = (
		'manage','manage_main',
		'manage_addZMSTeaserElement','manage_addZMSNote',
		'manage_deleteObjs','manage_moveObjUp','manage_moveObjDown','manage_cutObjects','manage_copyObjects','manage_pasteObjs',
		'manage_properties','manage_changeProperties',
		'manage_rollbackVersionChanges','manage_requestVersionChanges',
		)
    __editorPermissions__ = (
		'manage_commitVersionChanges',
		)
    __administratorPermissions__ = (
		)
    __ac_permissions__=(
		('ZMS Author', __authorPermissions__),
		('ZMS Editor', __editorPermissions__),
		('ZMS Administrator', __administratorPermissions__),
		)

    # Properties.
    # -----------
    __obj_attrs__ = {
        # Changed by
        'change_uid':{'datatype':'LangString','xml':0,'lang_inherit':_globals.LI_FORBIDDEN},
        'change_dt':{'datatype':'LangDate','xml':0,'lang_inherit':_globals.LI_FORBIDDEN},
        # Versioned by
        'work_uid':{'datatype':'LangString','xml':0,'lang_inherit':_globals.LI_FORBIDDEN},
        'work_dt':{'datatype':'LangDate','xml':0,'lang_inherit':_globals.LI_FORBIDDEN},
        # Properties
        'sort_id':{'datatype':'string','xml':0},
        'active':{'datatype':'LangInt','type':'checkbox','lang_inherit':_globals.LI_OBLIGATE},
        'attr_active_start':{'datatype':'LangDate','lang_inherit':_globals.LI_OBLIGATE},
        'attr_active_end':{'datatype':'LangDate','lang_inherit':_globals.LI_OBLIGATE},
        'title':{'datatype':'LangString','size':40},
        'titleshort':{'datatype':'LangString','size':20},
        'titleimage':{'datatype':'LangImage'},
        'attr_alias':{'datatype':'int'},
        # Meta-Dictionaries        
        '$metadict':{'datatype':'MetaDict'},
    }


    # Management Interface.
    # ---------------------
    manage_main = HTMLFile('dtml/zmssysfolder/manage_main', globals()) 


    """
    ###############################################################################################    
    #
    #   CONSTRUCTOR
    #
    ###############################################################################################    
    """

    ###############################################################################################
    # ZMSSysFolder.recurse_updateVersion:
    #
    # Update version.
    ###############################################################################################
    def recurse_updateVersion(self, lang, manage_lang, REQUEST):
      message = ''
      
      # Process super-objects.
      message = message + ZMSObject.recurse_updateVersion(self,lang,manage_lang,REQUEST)
      
      # Process object.
      # [...]
      
      # ---------------------------------------------------------------------
      # 26.02.2002
      # Build #067: Activity-Toggle.
      # ---------------------------------------------------------------------
      if getattr(self.getDocumentElement(),'build','') < '067':
        for s_preview in [None,'preview']:
          req = {'preview':s_preview}
          ob = self.getObjVersion(req)
          for s_key in ['active']:
            for s_lang in self.getLanguages():
              attr = '%s_%s'%(s_key,s_lang)
              if not hasattr(ob,attr) or getattr(self,'build','') <= '067':
                active = getattr(ob,'attr_active_start_%s'%s_lang,None) is not None or \
                         getattr(ob,'attr_active_end_%s'%s_lang,None) is not None 
                setattr(ob,attr,active)
      
      # Return with message.
      return message


    # ---------------------------------------------------------------------------------------------
    #	ZMSSysFolder.getHref2IndexHtml:
    #
    #   Reference to index_html.
    # ---------------------------------------------------------------------------------------------
    def getHref2IndexHtml(self, REQUEST):
      href = ""
      href = href + self.absolute_url()
      href = href + "/index_html"
      if REQUEST.has_key('lang'): 
        href = href + '?lang=%s'%REQUEST['lang']
      if _globals.isPreviewRequest(REQUEST):
        href = href + '&preview=preview'
      return href

    # ---------------------------------------------------------------------------------------------
    #	ZMSSysFolder.getHref2SitemapHtml:
    #
    #   Reference to sitemap_html.
    # ---------------------------------------------------------------------------------------------
    def getHref2SitemapHtml(self, REQUEST): 
      return self.getParentNode().getHref2SitemapHtml(REQUEST)

    # ---------------------------------------------------------------------------------------------
    #	ZMSSysFolder.getDCCoverage
    # ---------------------------------------------------------------------------------------------
    def getDCCoverage(self, REQUEST): return self.getParentNode().getDCCoverage(REQUEST)


    """
    ###############################################################################################    
    ###  
    ###  Override methods from CopySupport
    ### 
    ###############################################################################################    
    """

    # ------------------------------------------------------------------------------------------
    #	ZMSSysFolder._get_id:
    #
    #	Allow containers to override the generation of
    #	object copy id by attempting to call its _get_id
    #	method, if it exists.
    # ------------------------------------------------------------------------------------------
    def _get_id(self, id):
      newId = id
      while newId in self.objectIds():
        newId = 'copy_of_%s'%newId
      return newId

###################################################################################################
